@@ -29,7 +29,7 @@ fn display_help(programe_name:String) {
     println!("{}", DESCRIPTION.unwrap_or("unknown"));
     println!("Usage:");
     println!("{} -f input file [-b][-c config file][-d fontsize][-D fontsize][-e][-F format][-g input file][-G #][-h]\
-    [-H height][-i][-I][-J][-l factor][-L][-m][-o output file][-O][-p][-r ratio][-s][-S]\
+    [-H height][-i][-I][-J][-l factor][-L][-m][-o output file][-O][-p][-P][-r ratio][-s][-S]\
     [-t threshold][-T #][-u threshold][-U #][-v][-W width]",programe_name);
     println!("    -b : open svg in browser");
     println!("    -c configfile: use a configuration file");
@@ -51,6 +51,7 @@ fn display_help(programe_name:String) {
     println!("    -o outputfile : set name of output file");
     println!("    -O switching nodes in order to minimise transfer crossings (under development) ");
     println!("    -p : build a phylogram");
+    println!("    -P : pipe species tree uniformisation");
     println!("    -r ratio : set the ratio between width of species and gene tree.");
     println!("               Default 1.0, you usualy do not need to change it. ");
 
@@ -121,7 +122,7 @@ fn main()  {
     if args.len() == 1 {
          display_help(args[0].to_string());
     }
-    let mut opts = getopt::Parser::new(&args, "c:bd:D:ef:F:g:G:hH:iIJl:Lmo:Opr:sSt:T:u:U:vW:");
+    let mut opts = getopt::Parser::new(&args, "c:bd:D:ef:F:g:G:hH:iIJl:Lmo:OpPr:sSt:T:u:U:vW:");
     let mut infile_sh = String::new(); // symbiote host file
     let mut infile_gs = String::new(); // gene symbiote file
     let mut outfile = String::from("thirdkind.svg");
@@ -194,6 +195,7 @@ fn main()  {
                         };
                     },
                     Opt('p', None) => options.clado_flag = false,
+                    Opt('P', None) => options.uniform = true,
                     Opt('s', None) => options.species_only_flag = true,
                     Opt('S', None) => options.support = true,
                     Opt('t', Some(string)) => {
